pub struct IsoProjection { /* private fields */ }Expand description
IsoProjection creates a denser heatmap where each column is a week of the ISO calendar year and each row is a day of the week (starting with Monday).
Implementations